==> carbon-components-react-0.8.1.tgz: package/es/components/TourTooltip/TourTooltip.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React from 'react';
import PropTypes from 'prop-types';
import { settings } from '@rocketsoftware/carbon-components';
import cx from 'classnames';
import { Close20, Renew20 } from '@rocketsoftware/icons-react';
var prefix = settings.prefix;

var TourTooltip = /*#__PURE__*/function (_React$Component) {
  _inherits(TourTooltip, _React$Component);

  var _super = _createSuper(TourTooltip);

  function TourTooltip(props) {
    var _this;

    _classCallCheck(this, TourTooltip);

    _this = _super.call(this, props);
    _this.state = {
      flipped: false
    };
    return _this;
  }

  _createClass(TourTooltip, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          title = _this$props.title,
          description = _this$props.description,
          closeButtonAriaLabel = _this$props.closeButtonAriaLabel,
          nextLabel = _this$props.nextLabel,
          prevLabel = _this$props.prevLabel,
          onNext = _this$props.onNext,
          onPrev = _this$props.onPrev,
          onClose = _this$props.onClose,
          disableNext = _this$props.disableNext,
          disablePrev = _this$props.disablePrev,
          hideNext = _this$props.hideNext,
          hidePrev = _this$props.hidePrev,
          hideClose = _this$props.hideClose,
          enableFlip = _this$props.enableFlip,
          flipped = _this$props.flipped,
          onFlip = _this$props.onFlip,
          flippedTitle = _this$props.flippedTitle,
          flippedDescription = _this$props.flippedDescription,
          flipButtonAriaLabel = _this$props.flipButtonAriaLabel,
          flipBeforeClose = _this$props.flipBeforeClose;
      var next = disableNext ? undefined : onNext;
      var prev = disablePrev ? undefined : onPrev;
      var close = onClose;
      var controlled = flipped === true || flipped === false;
      var flipStatus = controlled ? flipped : this.state.flipped;
      var flipTooltip = controlled ? onFlip : function () {
        return _this2.setState({
          flipped: !_this2.state.flipped
        });
      };
      return /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefix, "--tour-tooltip--container")
      }, /*#__PURE__*/React.createElement("div", {
        className: cx("".concat(prefix, "--tour-tooltip"), {
          flipped: flipStatus
        })
      }, /*#__PURE__*/React.createElement(TooltipFace, {
        flip: flipTooltip,
        flipBeforeClose: flipBeforeClose,
        enableFlip: enableFlip,
        close: close,
        hideClose: hideClose,
        flipButtonAriaLabel: flipButtonAriaLabel,
        closeButtonAriaLabel: closeButtonAriaLabel,
        front: true,
        title: title,
        body: description
      }, !(hideNext && hidePrev) && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefix, "--tour-tooltip__action-group")
      }, !hidePrev && /*#__PURE__*/React.createElement("button", {
        onClick: prev,
        disabled: disablePrev,
        className: "".concat(prefix, "--btn ").concat(prefix, "--btn--secondary ").concat(prefix, "--btn--sm")
      }, prevLabel), !hideNext && /*#__PURE__*/React.createElement("button", {
        onClick: next,
        disabled: disableNext,
        className: "".concat(prefix, "--btn ").concat(prefix, "--btn--primary ").concat(prefix, "--btn--sm")
      }, nextLabel))), (enableFlip || flipBeforeClose) && /*#__PURE__*/React.createElement(TooltipFace, {
        enableFlip: enableFlip,
        flip: flipTooltip,
        flipBeforeClose: flipBeforeClose,
        close: close,
        flipButtonAriaLabel: flipButtonAriaLabel,
        closeButtonAriaLabel: closeButtonAriaLabel,
        front: false,
        title: flippedTitle,
        body: flippedDescription
      })));
    }
  }]);

  return TourTooltip;
}(React.Component);

var TooltipFace = function TooltipFace(props) {
  /* eslint-disable react/prop-types */
  var enableFlip = props.enableFlip,
      front = props.front,
      flip = props.flip,
      flipBeforeClose = props.flipBeforeClose,
      flipButtonAriaLabel = props.flipButtonAriaLabel,
      close = props.close,
      closeButtonAriaLabel = props.closeButtonAriaLabel,
      title = props.title,
      body = props.body,
      hideClose = props.hideClose;
  /* eslint-enable react/prop-types */

  return /*#__PURE__*/React.createElement("div", {
    className: cx("".concat(prefix, "--tour-tooltip__face"), "".concat(prefix, "--tour-tooltip--").concat(front ? 'front' : 'back'))
  }, /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefix, "--tour-tooltip__header")
  }, !hideClose && /*#__PURE__*/React.createElement("button", {
    className: "".concat(prefix, "--tour-tooltip__close-button"),
    type: "button",
    onClick: front && flipBeforeClose ? flip : close,
    "aria-label": closeButtonAriaLabel
  }, /*#__PURE__*/React.createElement(Close20, {
    className: "".concat(prefix, "--tour-tooltip__close--icon")
  })), enableFlip && /*#__PURE__*/React.createElement("button", {
    className: "".concat(prefix, "--tour-tooltip__flip-button"),
    type: "button",
    onClick: flip,
    "aria-label": flipButtonAriaLabel
  }, /*#__PURE__*/React.createElement(Renew20, {
    className: "".concat(prefix, "--tour-tooltip__flip--icon")
  })), /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefix, "--tour-tooltip__title")
  }, title)), /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefix, "--tour-tooltip__body")
  }, body), props.children // eslint-disable-line react/prop-types
  );
};

TourTooltip.propTypes = {
  /**
   * Primary tooltip title
   */
  title: PropTypes.string,

  /**
   * Primary tooltip content
   */
  description: PropTypes.string,

  /**
   * Optional display text for the "next" button
   */
  nextLabel: PropTypes.string,

  /**
   * Optional display text for the "previous" button
   */
  prevLabel: PropTypes.string,

  /**
   * Accessibility label text for the "close" button
   */
  closeButtonAriaLabel: PropTypes.string,

  /**
   * Accessibility label text for the "flip" button
   */
  flipButtonAriaLabel: PropTypes.string,

  /**
   * Optionally specify whether the "next"" button should be disabled
   */
  disableNext: PropTypes.bool,

  /**
   * Optionally specify whether the "previous" button should be disabled
   */
  disablePrev: PropTypes.bool,

  /**
   * Optionally specify whether the "next"" button should be hidden
   */
  hideNext: PropTypes.bool,

  /**
   * Optionally specify whether the "previous" button should be hidden
   */
  hidePrev: PropTypes.bool,

  /**
   * Function to be called when "next" is clicked
   */
  onNext: PropTypes.func,

  /**
   * Function to be called when "prev" is clicked
   */
  onPrev: PropTypes.func,

  /**
   * Function to be called when "close" is clicked
   */
  onClose: PropTypes.func,

  /**
   * If true, the tooltip can be flipped over to expose more content. The back
   * face displays a title and description, much like the front. As with the front side,
   * the provided description can be a node to allow for custom content rendering.
   */
  enableFlip: PropTypes.bool,

  /**
   * If provided, the tooltip's flip state will be controlled by this prop.
   */
  flipped: PropTypes.bool,

  /**
   * Callback used to change the flip state. Should be used in conjunction with the `flipped` prop.
   */
  onFlip: PropTypes.func,

  /**
   * Secondary tooltip title, visible when tooltip is flipped.
   */
  flippedTitle: PropTypes.string,

  /**
   * Secondary tooltip content, visible when tooltip is flipped.
   */
  flippedDescription: PropTypes.string,

  /**
   * Supports an alternative use case for the flipped case where it will first flip to that face and then close
   * on second click.
   */
  flipBeforeClose: PropTypes.bool
};
TourTooltip.defaultProps = {
  nextLabel: 'Next',
  prevLabel: 'Previous',
  closeButtonAriaLabel: 'Close',
  flipButtonAriaLabel: 'Flip',
  hideNext: false,
  hidePrev: false,
  hideClose: false,
  flipBeforeClose: false
};
export default TourTooltip;

==> carbon-components-react-2.0.5.tgz: package/es/components/TourTooltip/TourTooltip.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React from 'react';
import PropTypes from 'prop-types';
import { settings } from '@rocketsoftware/carbon-components';
import cx from 'classnames';
import { Close20, Renew20 } from '@rocketsoftware/icons-react';
var prefix = settings.prefix;

var TourTooltip = /*#__PURE__*/function (_React$Component) {
  _inherits(TourTooltip, _React$Component);

  var _super = _createSuper(TourTooltip);

  function TourTooltip(props) {
    var _this;

    _classCallCheck(this, TourTooltip);

    _this = _super.call(this, props);
    _this.state = {
      flipped: false
    };
    return _this;
  }

  _createClass(TourTooltip, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          title = _this$props.title,
          description = _this$props.description,
          closeButtonAriaLabel = _this$props.closeButtonAriaLabel,
          nextLabel = _this$props.nextLabel,
          prevLabel = _this$props.prevLabel,
          onNext = _this$props.onNext,
          onPrev = _this$props.onPrev,
          onClose = _this$props.onClose,
          disableNext = _this$props.disableNext,
          disablePrev = _this$props.disablePrev,
          hideNext = _this$props.hideNext,
          hidePrev = _this$props.hidePrev,
          hideClose = _this$props.hideClose,
          enableFlip = _this$props.enableFlip,
          flipped = _this$props.flipped,
          onFlip = _this$props.onFlip,
          flippedTitle = _this$props.flippedTitle,
          flippedDescription = _this$props.flippedDescription,
          flipButtonAriaLabel = _this$props.flipButtonAriaLabel,
          flipBeforeClose = _this$props.flipBeforeClose;
      var next = disableNext ? undefined : onNext;
      var prev = disablePrev ? undefined : onPrev;
      var close = onClose;
      var controlled = flipped === true || flipped === false;
      var flipStatus = controlled ? flipped : this.state.flipped;
      var flipTooltip = controlled ? onFlip : function () {
        return _this2.setState({
          flipped: !_this2.state.flipped
        });
      };
      return /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefix, "--tour-tooltip--container")
      }, /*#__PURE__*/React.createElement("div", {
        className: cx("".concat(prefix, "--tour-tooltip"), {
          flipped: flipStatus
        })
      }, /*#__PURE__*/React.createElement(TooltipFace, {
        flip: flipTooltip,
        flipBeforeClose: flipBeforeClose,
        enableFlip: enableFlip,
        close: close,
        hideClose: hideClose,
        flipButtonAriaLabel: flipButtonAriaLabel,
        closeButtonAriaLabel: closeButtonAriaLabel,
        front: true,
        title: title,
        body: description
      }, !(hideNext && hidePrev) && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefix, "--tour-tooltip__action-group")
      }, !hidePrev && /*#__PURE__*/React.createElement("button", {
        onClick: prev,
        disabled: disablePrev,
        className: "".concat(prefix, "--btn ").concat(prefix, "--btn--secondary ").concat(prefix, "--btn--sm")
      }, prevLabel), !hideNext && /*#__PURE__*/React.createElement("button", {
        onClick: next,
        disabled: disableNext,
        className: "".concat(prefix, "--btn ").concat(prefix, "--btn--primary ").concat(prefix, "--btn--sm")
      }, nextLabel))), (enableFlip || flipBeforeClose) && /*#__PURE__*/React.createElement(TooltipFace, {
        enableFlip: enableFlip,
        flip: flipTooltip,
        flipBeforeClose: flipBeforeClose,
        close: close,
        flipButtonAriaLabel: flipButtonAriaLabel,
        closeButtonAriaLabel: closeButtonAriaLabel,
        front: false,
        title: flippedTitle,
        body: flippedDescription
      })));
    }
  }]);

  return TourTooltip;
}(React.Component);

var TooltipFace = function TooltipFace(props) {
  /* eslint-disable react/prop-types */
  var enableFlip = props.enableFlip,
      front = props.front,
      flip = props.flip,
      flipBeforeClose = props.flipBeforeClose,
      flipButtonAriaLabel = props.flipButtonAriaLabel,
      close = props.close,
      closeButtonAriaLabel = props.closeButtonAriaLabel,
      title = props.title,
      body = props.body,
      hideClose = props.hideClose;
  /* eslint-enable react/prop-types */

  return /*#__PURE__*/React.createElement("div", {
    className: cx("".concat(prefix, "--tour-tooltip__face"), "".concat(prefix, "--tour-tooltip--").concat(front ? 'front' : 'back'))
  }, /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefix, "--tour-tooltip__header")
  }, !hideClose && /*#__PURE__*/React.createElement("button", {
    className: "".concat(prefix, "--tour-tooltip__close-button"),
    type: "button",
    onClick: front && flipBeforeClose ? flip : close,
    "aria-label": closeButtonAriaLabel
  }, /*#__PURE__*/React.createElement(Close20, {
    className: "".concat(prefix, "--tour-tooltip__close--icon")
  })), enableFlip && /*#__PURE__*/React.createElement("button", {
    className: "".concat(prefix, "--tour-tooltip__flip-button"),
    type: "button",
    onClick: flip,
    "aria-label": flipButtonAriaLabel
  }, /*#__PURE__*/React.createElement(Renew20, {
    className: "".concat(prefix, "--tour-tooltip__flip--icon")
  })), /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefix, "--tour-tooltip__title")
  }, title)), /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefix, "--tour-tooltip__body")
  }, body), props.children // eslint-disable-line react/prop-types
  );
};

TourTooltip.propTypes = {
  /**
   * Primary tooltip title
   */
  title: PropTypes.string,

  /**
   * Primary tooltip content
   */
  description: PropTypes.string,

  /**
   * Optional display text for the "next" button
   */
  nextLabel: PropTypes.string,

  /**
   * Optional display text for the "previous" button
   */
  prevLabel: PropTypes.string,

  /**
   * Accessibility label text for the "close" button
   */
  closeButtonAriaLabel: PropTypes.string,

  /**
   * Accessibility label text for the "flip" button
   */
  flipButtonAriaLabel: PropTypes.string,

  /**
   * Optionally specify whether the "next"" button should be disabled
   */
  disableNext: PropTypes.bool,

  /**
   * Optionally specify whether the "previous" button should be disabled
   */
  disablePrev: PropTypes.bool,

  /**
   * Optionally specify whether the "next"" button should be hidden
   */
  hideNext: PropTypes.bool,

  /**
   * Optionally specify whether the "previous" button should be hidden
   */
  hidePrev: PropTypes.bool,

  /**
   * Function to be called when "next" is clicked
   */
  onNext: PropTypes.func,

  /**
   * Function to be called when "prev" is clicked
   */
  onPrev: PropTypes.func,

  /**
   * Function to be called when "close" is clicked
   */
  onClose: PropTypes.func,

  /**
   * If true, the tooltip can be flipped over to expose more content. The back
   * face displays a title and description, much like the front. As with the front side,
   * the provided description can be a node to allow for custom content rendering.
   */
  enableFlip: PropTypes.bool,

  /**
   * If provided, the tooltip's flip state will be controlled by this prop.
   */
  flipped: PropTypes.bool,

  /**
   * Callback used to change the flip state. Should be used in conjunction with the `flipped` prop.
   */
  onFlip: PropTypes.func,

  /**
   * Secondary tooltip title, visible when tooltip is flipped.
   */
  flippedTitle: PropTypes.string,

  /**
   * Secondary tooltip content, visible when tooltip is flipped.
   */
  flippedDescription: PropTypes.string,

  /**
   * Supports an alternative use case for the flipped case where it will first flip to that face and then close
   * on second click.
   */
  flipBeforeClose: PropTypes.bool
};
TourTooltip.defaultProps = {
  nextLabel: 'Next',
  prevLabel: 'Previous',
  closeButtonAriaLabel: 'Close',
  flipButtonAriaLabel: 'Flip',
  hideNext: false,
  hidePrev: false,
  hideClose: false,
  flipBeforeClose: false
};
export default TourTooltip;
